@@ -18,7 +18,7 @@ class HTTPRequestBase(ABC):
     BASE_URL = "https://discord.com/api/v9"
 
     @abstractmethod
-    def request(self, route: str, meth: str, body: dict = None, is_json: bool = False, *, retry: int = 3, **kwargs):
+    def request(self, route: str, meth: str, body: dict = None, *, is_json: bool = False, reason_header: str = None, retry: int = 3, **kwargs):
         """
         This function should wrap :meth:`._request` with rate limit handling.
         :return:
@@ -26,7 +26,7 @@ class HTTPRequestBase(ABC):
         pass
 
     @abstractmethod
-    def _request(self, route: str, meth: str, body: dict = None, is_json: bool = False, **kwargs) -> typing.Tuple[int, dict]:
+    def _request(self, route: str, meth: str, body: dict = None, is_json: bool = False, reason_header: str = None, **kwargs) -> typing.Tuple[int, dict]:
         """
         HTTP Requesting part.
         :return: Tuple[int, dict]
@@ -191,7 +191,7 @@ class HTTPRequestBase(ABC):
                        content: str = None,
                        nonce: typing.Union[int, str] = None,
                        tts: bool = False,
-                       embed: dict = None,
+                       embeds: typing.List[dict] = None,
                        allowed_mentions: dict = None,
                        message_reference: dict = None,
                        components: typing.List[dict] = None):
@@ -202,19 +202,19 @@ class HTTPRequestBase(ABC):
         :param content: Content of the message.
         :param nonce:
         :param tts: Whether this message is TTS.
-        :param embed: Embed of the message.
+        :param embeds: List of embeds of the message.
         :param allowed_mentions: Allowed mentions of the message.
         :param message_reference: Message to reference.
         :param components: Components of the message.
         :return: Message object dict.
         """
-        if not (content or embed):
+        if not (content or embeds):
             raise ValueError("either content or embed must be passed.")
         body = {}
         if content is not None:
             body["content"] = content
-        if embed is not None:
-            body["embed"] = embed
+        if embeds is not None:
+            body["embeds"] = embeds
         if nonce is not None:
             body["nonce"] = nonce
         if tts is not None:
@@ -234,7 +234,7 @@ class HTTPRequestBase(ABC):
                                   files: typing.List[io.FileIO] = None,
                                   nonce: typing.Union[int, str] = None,
                                   tts: bool = None,
-                                  embed: dict = None,
+                                  embeds: typing.List[dict] = None,
                                   allowed_mentions: dict = None,
                                   message_reference: dict = None,
                                   components: typing.List[dict] = None):
@@ -246,7 +246,7 @@ class HTTPRequestBase(ABC):
         :param files: Files of the message.
         :param nonce:
         :param tts: Whether this message is TTS.
-        :param embed: Embed of the message.
+        :param embeds: List of embeds of the message.
         :param allowed_mentions: Allowed mentions of the message.
         :param message_reference: Message to reference.
         :param components: Components of the message.
@@ -324,7 +324,7 @@ class HTTPRequestBase(ABC):
                      channel_id,
                      message_id,
                      content: str = None,
-                     embed: dict = None,
+                     embeds: typing.List[dict] = None,
                      flags: int = None,
                      allowed_mentions: dict = None,
                      attachments: typing.List[dict] = None,
@@ -335,7 +335,7 @@ class HTTPRequestBase(ABC):
         :param channel_id: ID of the channel.
         :param message_id: ID of the message to edit.
         :param content: Content of the message.
-        :param embed: Embed of the message.
+        :param embeds: List of embeds of the message.
         :param flags: Flags of the message.
         :param allowed_mentions: Allowed mentions of the message.
         :param attachments: Attachments to keep.
@@ -345,8 +345,8 @@ class HTTPRequestBase(ABC):
         body = {}
         if content is not None:
             body["content"] = content
-        if embed is not None:
-            body["embed"] = embed
+        if embeds is not None:
+            body["embeds"] = embeds
         if flags is not None:
             body["flags"] = flags
         if allowed_mentions is not None:
@@ -362,7 +362,7 @@ class HTTPRequestBase(ABC):
                                 channel_id,
                                 message_id,
                                 content: str = None,
-                                embed: dict = None,
+                                embeds: typing.List[dict] = None,
                                 flags: int = None,
                                 files: typing.List[io.FileIO] = None,
                                 allowed_mentions: dict = None,
@@ -374,7 +374,7 @@ class HTTPRequestBase(ABC):
         :param channel_id: ID of the channel.
         :param message_id: ID of the message to edit.
         :param content: Content of the message.
-        :param embed: Embed of the message.
+        :param embeds: List of embeds of the message.
         :param flags: Flags of the message.
         :param files: Files of the message.
         :param allowed_mentions: Allowed mentions of the message.
@@ -688,6 +688,33 @@ class HTTPRequestBase(ABC):
         body = {"name": name, "roles": roles}
         return self.request(f"/guilds/{guild_id}/emojis/{emoji_id}", "PATCH", body, is_json=True)
 
+    # Guild Requests
+
+    def remove_guild_member(self, guild_id, user_id):
+        """
+        Sends remove guild member request.
+
+        :param guild_id: ID of the guild.
+        :param user_id: ID of the user to remove.
+        """
+        return self.request(f"/guilds/{guild_id}/members/{user_id}", "DELETE")
+
+    def create_guild_ban(self, guild_id, user_id, delete_message_days: int = None, reason: str = None):
+        """
+        Sends create guild ban request.
+
+        :param guild_id: ID of the guild.
+        :param user_id: ID of the user to ban.
+        :param delete_message_days: Days of message sent by banned user to delete.
+        :param reason: Reason for banning user.
+        """
+        body = {}
+        if delete_message_days is not None:
+            body["delete_message_days"] = delete_message_days
+        if reason is not None:
+            body["reason"] = reason
+        return self.request(f"/guilds/{guild_id}/bans/{user_id}", "PUT", body, is_json=True)
+
     # Webhook Requests
 
     def create_webhook(self, channel_id, name: str, avatar: str = None):
